@@ -140,6 +140,11 @@ class FeedItem:
         )
         if media_content is not None:
             return media_content
+        media_thumbnail = self.get_image_from_media_thumbnail(
+            entry.get("media_thumbnail", {})
+        )
+        if media_thumbnail is not None:
+            return media_thumbnail
         links = self.get_image_from_links(entry.get("links", {}))
         if links is not None:
             return links
@@ -165,6 +170,16 @@ class FeedItem:
                 if m is not None:
                     return m
 
+    def get_image_from_media_thumbnail(self, media_thumbnail):
+        """
+        tries to get an image link from the "media_thumbnail" data
+        """
+        if isinstance(media_thumbnail, list) and len(media_thumbnail):
+            for media in media_thumbnail:
+                m = self.find_image_link(media.get("url", ""))
+                if m is not None:
+                    return m
+
     def get_image_from_links(self, links):
         """
         tries to get an image link from the "links" data
@@ -205,7 +220,7 @@ class FeedItem:
         search a string for an embedded image link
         """
         m = re.search(
-            "(https?:\/\/[^'\"]*\.(gif|jpg|jpeg|png))", content, re.IGNORECASE
+            "(https?:\/\/[^'\"]*\.(gif|jpe?g|png|tiff?|webp))", content, re.IGNORECASE
         )
         if m:
             return m.group(1)
@@ -400,11 +415,14 @@ def publish_items(db, client, args=None):
         query = query + " LIMIT %s" % args.limit
     timeout = int(time.time() - args.timeout * 3600)
     for row in db.execute(query, (args.feed_id, timeout)):
-        if not args.quiet:
-            print("Publishing %s\t%s" % (args.feed_id, row["guid"]))
-        if client.publish(row, args):
-            db.execute("UPDATE feeds SET posted = 1 WHERE guid = ?", (row["guid"],))
-            db.commit()
+        try:
+            if not args.quiet:
+                print("Publishing %s\t%s" % (args.feed_id, row["guid"]))
+            if client.publish(row, args):
+                db.execute("UPDATE feeds SET posted = 1 WHERE guid = ?", (row["guid"],))
+                db.commit()
+        except Exception as e:
+            print("Error: %s" % e)
 
 
 def parse_args():
