@@ -134,22 +134,26 @@ class TestFeedItem(unittest.TestCase):
     @mock.patch.object(FeedItem, "get_image_from_summary_detail")
     @mock.patch.object(FeedItem, "get_image_from_content")
     @mock.patch.object(FeedItem, "get_image_from_links")
+    @mock.patch.object(FeedItem, "get_image_from_media_thumbnail")
     @mock.patch.object(FeedItem, "get_image_from_media_content")
     def test_get_image(
         self,
         mock_get_image_from_media_content,
+        mock_get_image_from_media_thumbnail,
         mock_get_image_from_links,
         mock_get_image_from_content,
         mock_get_image_from_summary_detail,
         mock_get_image_from_summary,
     ):
         mock_get_image_from_media_content.return_value = None
+        mock_get_image_from_media_thumbnail.return_value = None
         mock_get_image_from_links.return_value = None
         mock_get_image_from_content.return_value = None
         mock_get_image_from_summary_detail.return_value = None
         mock_get_image_from_summary.return_value = None
         FeedItem.get_image(FeedItem, {})
         mock_get_image_from_media_content.assert_called()
+        mock_get_image_from_media_thumbnail.assert_called()
         mock_get_image_from_links.assert_called()
         mock_get_image_from_content.assert_called()
         mock_get_image_from_summary_detail.assert_called()
@@ -164,6 +168,15 @@ class TestFeedItem(unittest.TestCase):
         self.assertIsNone(FeedItem.get_image_from_media_content(FeedItem, []))
         self.assertIsNone(FeedItem.get_image_from_media_content(FeedItem, {}))
 
+    @mock.patch.object(FeedItem, "find_image_link")
+    def test_get_image_from_media_thumbnail(self, mock_find_image_link):
+        mock_find_image_link.return_value = "IMAGE"
+        self.assertEqual(
+            FeedItem.get_image_from_media_thumbnail(FeedItem, [{"url": ""}]), "IMAGE"
+        )
+        self.assertIsNone(FeedItem.get_image_from_media_thumbnail(FeedItem, []))
+        self.assertIsNone(FeedItem.get_image_from_media_thumbnail(FeedItem, {}))
+
     def test_get_image_from_links(self):
         self.assertEqual(
             FeedItem.get_image_from_links(
@@ -194,6 +207,13 @@ class TestFeedItem(unittest.TestCase):
         self.assertEqual(FeedItem.get_image_from_summary(FeedItem, "summary"), "IMAGE")
 
     def test_find_image_link(self):
+        self.assertEqual(
+            FeedItem.find_image_link(
+                FeedItem,
+                "This is a link -->https://example.com/test.PNG<-- This is a link",
+            ),
+            "https://example.com/test.PNG",
+        )
         self.assertEqual(
             FeedItem.find_image_link(
                 FeedItem,
@@ -201,6 +221,34 @@ class TestFeedItem(unittest.TestCase):
             ),
             "https://example.com/test.png",
         )
+        self.assertEqual(
+            FeedItem.find_image_link(
+                FeedItem,
+                "This is a link -->https://example.com/test.jpg<-- This is a link",
+            ),
+            "https://example.com/test.jpg",
+        )
+        self.assertEqual(
+            FeedItem.find_image_link(
+                FeedItem,
+                "This is a link -->https://example.com/test.jpeg<-- This is a link",
+            ),
+            "https://example.com/test.jpeg",
+        )
+        self.assertEqual(
+            FeedItem.find_image_link(
+                FeedItem,
+                "This is a link -->https://example.com/test.tif<-- This is a link",
+            ),
+            "https://example.com/test.tif",
+        )
+        self.assertEqual(
+            FeedItem.find_image_link(
+                FeedItem,
+                "This is a link -->https://example.com/test.webp<-- This is a link",
+            ),
+            "https://example.com/test.webp",
+        )
         self.assertIsNone(
             FeedItem.find_image_link(
                 FeedItem, "This is a NOT link -->NOT A LINK<-- This is NOT a link"
